@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -15,9 +15,9 @@
 
   MagickCore API methods prefix.
 
-  nm .libs/libMagickCore.a | grep ' T ' | \
-    awk '{ printf("#define %s  PrependMagickMethod(%s)\n", $3, $3); }' | \
-    sort
+  nm -p magick/.libs/libMagickCore.a | grep ' T ' | egrep -vi '(Magick)|(lt_)' | \
+     egrep -v '(MagickError)|(MagickFatalError)|(MagickWarning)|(ThrowException)' | \
+    awk '{ printf("#define %s  PrependMagickMethod(%s)\n", $3, $3); }' | sort
 */
 #ifndef _MAGICKCORE_METHOD_H
 #define _MAGICKCORE_METHOD_H
@@ -905,6 +905,7 @@ extern "C" {
 #define RegisterIPLImage  PrependMagickMethod(RegisterIPLImage)
 #define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
 #define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
+#define RegisterJSONImage  PrependMagickMethod(RegisterJSONImage)
 #define RegisterLABELImage  PrependMagickMethod(RegisterLABELImage)
 #define RegisterMCPImage  PrependMagickMethod(RegisterMACImage)
 #define RegisterMAGICKImage  PrependMagickMethod(RegisterMAGICKImage)
@@ -946,6 +947,7 @@ extern "C" {
 #define RegisterRLAImage  PrependMagickMethod(RegisterRLAImage)
 #define RegisterRLEImage  PrependMagickMethod(RegisterRLEImage)
 #define RegisterSCRImage  PrependMagickMethod(RegisterSCRImage)
+#define RegisterSREENSHOTImage  PrependMagickMethod(RegisterSCREENSHOTImage)
 #define RegisterSCTImage  PrependMagickMethod(RegisterSCTImage)
 #define RegisterSFWImage  PrependMagickMethod(RegisterSFWImage)
 #define RegisterSGIImage  PrependMagickMethod(RegisterSGIImage)
@@ -966,6 +968,7 @@ extern "C" {
 #define RegisterVICARImage  PrependMagickMethod(RegisterVICARImage)
 #define RegisterVIDImage  PrependMagickMethod(RegisterVIDImage)
 #define RegisterVIFFImage  PrependMagickMethod(RegisterVIFFImage)
+#define RegisterVIPSImage  PrependMagickMethod(RegisterVIPSImage)
 #define RegisterWBMPImage  PrependMagickMethod(RegisterWBMPImage)
 #define RegisterWMFImage  PrependMagickMethod(RegisterWMFImage)
 #define RegisterWPGImage  PrependMagickMethod(RegisterWPGImage)
@@ -1032,6 +1035,8 @@ extern "C" {
 #define RGBTransformImage  PrependMagickMethod(RGBTransformImage)
 #define RollImage  PrependMagickMethod(RollImage)
 #define RotateImage  PrependMagickMethod(RotateImage)
+#define RotationalBlurImageChannel  PrependMagickMethod(RotationalBlurImageChannel)
+#define RotationalBlurImage  PrependMagickMethod(RotationalBlurImage)
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
 #define ScaleResampleFilter  PrependMagickMethod(ScaleResampleFilter)
@@ -1068,12 +1073,14 @@ extern "C" {
 #define SetImageColorspace  PrependMagickMethod(SetImageColorspace)
 #define SetImageDepth  PrependMagickMethod(SetImageDepth)
 #define SetImageExtent  PrependMagickMethod(SetImageExtent)
+#define SetImageGray  PrependMagickMethod(SetImageGray)
 #define SetImageInfoBlob  PrependMagickMethod(SetImageInfoBlob)
 #define SetImageInfoFile  PrependMagickMethod(SetImageInfoFile)
 #define SetImageInfo  PrependMagickMethod(SetImageInfo)
 #define SetImageInfoProgressMonitor  PrependMagickMethod(SetImageInfoProgressMonitor)
 #define SetImageList  PrependMagickMethod(SetImageList)
 #define SetImageMask  PrependMagickMethod(SetImageMask)
+#define SetImageMonochrome  PrependMagickMethod(SetImageMonochrome)
 #define SetImageOpacity  PrependMagickMethod(SetImageOpacity)
 #define SetImageOption  PrependMagickMethod(SetImageOption)
 #define SetImagePixels  PrependMagickMethod(SetImagePixels)
@@ -1235,6 +1242,7 @@ extern "C" {
 #define UnregisterIPLImage  PrependMagickMethod(UnregisterIPLImage)
 #define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
 #define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
+#define UnregisterJSONImage  PrependMagickMethod(UnregisterJSONImage)
 #define UnregisterLABELImage  PrependMagickMethod(UnregisterLABELImage)
 #define UnregisterMACImage  PrependMagickMethod(UnregisterMACImage)
 #define UnregisterMAGICKImage  PrependMagickMethod(UnregisterMAGICKImage)
@@ -1276,6 +1284,7 @@ extern "C" {
 #define UnregisterRLAImage  PrependMagickMethod(UnregisterRLAImage)
 #define UnregisterRLEImage  PrependMagickMethod(UnregisterRLEImage)
 #define UnregisterSCRImage  PrependMagickMethod(UnregisterSCRImage)
+#define UnregisterSCREENSHOTImage  PrependMagickMethod(UnregisterSCREENSHOTImage)
 #define UnregisterSCTImage  PrependMagickMethod(UnregisterSCTImage)
 #define UnregisterSFWImage  PrependMagickMethod(UnregisterSFWImage)
 #define UnregisterSGIImage  PrependMagickMethod(UnregisterSGIImage)
@@ -1296,6 +1305,7 @@ extern "C" {
 #define UnregisterVICARImage  PrependMagickMethod(UnregisterVICARImage)
 #define UnregisterVIDImage  PrependMagickMethod(UnregisterVIDImage)
 #define UnregisterVIFFImage  PrependMagickMethod(UnregisterVIFFImage)
+#define UnregisterVIPSImage  PrependMagickMethod(UnregisterVIPSImage)
 #define UnregisterWBMPImage  PrependMagickMethod(UnregisterWBMPImage)
 #define UnregisterWMFImage  PrependMagickMethod(UnregisterWMFImage)
 #define UnregisterWPGImage  PrependMagickMethod(UnregisterWPGImage)
