@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,39 +26,32 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2012 ImageMagick Studio LLC"
-#define MagickSVNRevision  "8219"
-#define MagickLibVersion  0x677
-#define MagickLibVersionText  "6.7.7"
-#define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-7"
-#define MagickLibInterface  5
-#define MagickLibMinInterface  5
-#define MagickReleaseDate  "2014-08-01"
-#define MagickChangeDate   "20120606"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
-#if defined(MAGICKCORE_OPENMP_SUPPORT)
-#define MagickOpenMPFeature  "OpenMP "
+#define MagickCopyright  "Copyright (C) 1999-2016 ImageMagick Studio LLC"
+#define MagickLibVersion  0x693
+#define MagickLibVersionText  "6.9.3"
+#define MagickLibVersionNumber  2,0,0
+#define MagickLibAddendum  "-0"
+#define MagickLibInterface  2
+#define MagickLibMinInterface  2
+#if defined(_WINDOWS)
+#  if defined(_WIN64)
+#    define MagickPlatform "x64"
+#  else
+#    define MagickPlatform "x86"
+#  endif
 #else
-#define MagickOpenMPFeature  " "
+#define MagickPlatform  "mips64"
 #endif
-#if defined(MAGICKCORE_OPENCL_SUPPORT)
-#define MagickOpenCLFeature  "OpenCL "
-#else
-#define MagickOpenCLFeature  " "
-#endif
-#if defined(MAGICKCORE_HDRI_SUPPORT)
-#define MagickHDRIFeature  "HDRI "
-#else
-#define MagickHDRIFeature  " "
-#endif
-#if defined(MAGICKCORE_ZERO_CONFIGURATION_SUPPORT)
-#define MagickZeroConfigurationFeature  "Zero-Configuration "
-#else
-#define MagickZeroConfigurationFeature  " "
-#endif
-#define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature MagickZeroConfigurationFeature
+#define MagickppLibVersionText  "6.9.3"
+#define MagickppLibVersionNumber  6:0:0
+#define MagickppLibAddendum  "-0"
+#define MagickppLibInterface  6
+#define MagickppLibMinInterface  6
+#define MagickReleaseDate  "2016-02-29"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
+#define MagickAuthoritativeLicense  \
+  "http://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "http://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -70,27 +63,33 @@ extern "C" {
 #define MagickQuantumRange  "4294967295"
 #elif (MAGICKCORE_QUANTUM_DEPTH == 64)
 #define MagickQuantumDepth  "Q64"
-#define MagickQuantumRange  "18446744073709551615"
+#define MagickQuantumRange  "18446744073709551615.0"
 #else
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
 #define MagickVersion  \
   MagickPackageName " " MagickLibVersionText MagickLibAddendum " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickAuthoritativeURL
+  MagickQuantumDepth " " MagickPlatform " " MagickReleaseDate " " \
+  MagickAuthoritativeURL
 
 extern MagickExport char
   *GetMagickHomeURL(void);
 
 extern MagickExport const char
   *GetMagickCopyright(void),
+  *GetMagickDelegates(void),
   *GetMagickFeatures(void),
+  *GetMagickLicense(void),
   *GetMagickPackageName(void),
   *GetMagickQuantumDepth(size_t *),
   *GetMagickQuantumRange(size_t *),
   *GetMagickReleaseDate(void),
   *GetMagickVersion(size_t *);
 
+extern MagickExport void
+  ListMagickVersion(FILE *);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
